@@ -25,13 +25,13 @@ module AttrExtras
       end
 
       def hash_args_required
-        @hash_args_required ||= hash_args.select { |name| name.to_s.end_with?(REQUIRED_SIGN) }.
-          map { |name| remove_required_sign(name) }
+        @hash_args_required ||= hash_args.select { |name| name.to_s.end_with?(REQUIRED_SIGN) }
+          .map { |name| remove_required_sign(name) }
       end
 
       def default_values
         @default_values ||= begin
-          default_values_hash = names.flatten.select { |name| name.is_a?(Hash) }.inject(:merge) || {}
+          default_values_hash = names.flatten.select { |name| name.is_a?(Hash) }.reduce(:merge) || {}
 
           default_values_hash.map { |name, value|
             [ remove_required_sign(name), value ]
